@REM */**********************************************************************\*
@REM **                                                                      **
@REM ** Licensed Materials - Property of IBM                                 **
@REM ** (C) Copyright IBM Corp. 2005, 2008  All Rights Reserved.             **
@REM **                                                                      **
@REM ** US Government Users Restricted Rights - Use, duplication, or         **
@REM ** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.    **
@REM **                                                                      **
@REM *\**********************************************************************/*
@echo off
REM ****************************************************************************************************
REM * Program description:                                                                             *
REM *    Atlas Update Driver                                                                           *
REM *                                                                                                  *
REM ****************************************************************************************************
@setlocal

set MYERRORLEVEL=0

REM Set current Drive and PATH
set CURRENT_MAIN_DRIVE=%~d0
set CURRENT_MAIN_PATH=%~dp0

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

set LOG=LOG_%~n0.txt
set LOGDIR=%~dp0\logs

REM Create LOG Directory if not already created
if not exist "%LOGDIR%" (
   mkdir "%LOGDIR%"
)

REM ###########################################################################
REM ##########      now read configuration from config file          ##########
REM ###########################################################################

echo ++++ %DATE%:%TIME% try loading Atlas configuration from .\atlas.config.bat
if exist .\atlas.config.bat call .\atlas.config.bat

REM ###########################################################################
REM ##########            **set config defaults**                    ##########
REM ###########################################################################

if not exist .\atlas.config.defaults.bat (
   echo ++++ %DATE%:%TIME% ERROR: atlas.config.defaults.bat is missing!
   set MYERRORLEVEL=1
   goto :EXIT
)

echo ++++ %DATE%:%TIME% loading Atlas defaults from .\atlas.config.bat
call .\atlas.config.defaults.bat

REM ###########################################################################
REM ##########            **set config defaults end**                ##########
REM ###########################################################################


REM ###########################################################################
REM ########## Stop WebSphere Application Server.                    ##########
REM ###########################################################################
set cmdline=call "%APP_SERVER_PROFILEPATH%\bin\stopServer.bat" %APP_SERVER_NAME% -username %WASADMIN% -password %WASPSWD%
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if "%MYERRORLEVEL%"=="-10" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
if not "%MYERRORLEVEL%"=="0" goto :EXIT

REM ###########################################################################
REM ########## Update Atlas Database                                 ##########
REM ###########################################################################
%CURRENT_MAIN_DRIVE%

if not exist ".\DB2\AdapterRelated\Las_adapterImport.bat" goto :noAdapter

set cmdline=call .\DB2\Configuration\ATLASDB.bat ".\DB2\AdapterRelated\Las_adapterImport.bat"
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

:noAdapter

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

goto :noHTTPServer
REM ###########################################################################
REM ########## Configure IBM HTTP Server                             ##########
REM ###########################################################################
if "%LAS_MachinType%"=="DBServer" goto :noHTTPServer

cd "Tracking GUI"
set cmdline=xcopy *.* "%IHSROOT%\htdocs\en_us\Tracking GUI\*.*" /H /E /V /Y
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=mkdir "%IHSROOT%\htdocs\en_us\reports" "%IHSROOT%\htdocs\en_us\archive" "%IHSROOT%\htdocs\en_us\search" "%IHSROOT%\htdocs\en_us\wsdl"
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if "%MYERRORLEVEL%"=="1" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
if not "%MYERRORLEVEL%"=="0" goto :EXIT

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

set cmdline=copy samples\EMailHandler.wsdl "%IHSROOT%\htdocs\en_us\wsdl\"
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT 

:noHTTPServer

goto :noToolsDir
REM ###########################################################################
REM ########## setup tools directory                                 ##########
REM ###########################################################################
set cmdline=mkdir c:\tools
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if "%MYERRORLEVEL%"=="1" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=copy samples\sampleSubscriber.bat c:\tools\
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=cscript //nologo .\WAS\scripts\updatePath.vbs c:\tools
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=cscript //nologo .\WAS\scripts\updatePath.vbs "%WASROOT%\java\bin"
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=xcopy "DB2\Tools\History\*.*" "c:\tools\history\" /H /E /V /Y
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

set cmdline=xcopy "samples\reports\*.*" "c:\tools\reports\" /H /E /V /Y
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

:noToolsDir
:WASCFG

REM ###########################################################################
REM ########## Configure WebSphere Application Server                ##########
REM ###########################################################################
REM if "%LAS_MachinType%"=="DBServer" goto :noWASServer

cd .\WAS\scripts
REM set cmdline=call ATLASWAS_MAIN.bat 
REM echo ++++ %DATE%:%TIME% Execute: %cmdline%
REM %cmdline%
REM set MYERRORLEVEL=%ERRORLEVEL%
REM echo ++++ %DATE%:%TIME% Executed: %cmdline%
REM echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
REM if not "%MYERRORLEVEL%"=="0" goto :EXIT


REM ###########################################################################
REM ########## Copy WebSphere Application Server JARs                ##########
REM ###########################################################################
set cmdline=call ATLASWAS_PreConfigWAS.bat %WASROOT% %WPROOT%
set logfile=%LOGDIR%\LOG_ATLASWAS_PreConfigWAS.txt
echo ++++ %DATE%:%TIME% Execute: %cmdline%
echo ++++ %DATE%:%TIME% Logfile: "%logfile%"
%cmdline% >>"%logfile%" 2>>&1
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

REM ###########################################################################
REM ########## Install EARs                                          ##########
REM ###########################################################################
set cmdline=call ATLASWAS_installEARs.bat %WASADMIN% %WASPSWD% %WASROOT%
set logfile=%LOGDIR%\LOG_ATLASWAS_installEARs.txt
echo ++++ %DATE%:%TIME% Execute: %cmdline%
echo ++++ %DATE%:%TIME% Logfile: "%logfile%"
%cmdline% >>"%logfile%" 2>>&1
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

goto :noEventDB
REM ###########################################################################
REM ########## Build Event Database                                  ##########
REM ###########################################################################
cd .\DB2\Configuration
set cmdline=call EVENTDB_MAIN.bat
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

:noEventDB

:noWASServer

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"


REM ###########################################################################
REM ########## Configure WebSphere Portal                            ##########
REM ###########################################################################
if "%LAS_MachinType%"=="DBServer" goto :noWPServer

cd .\WP\scripts
set cmdline=call ATLASWP_MAIN.bat %WASROOT% %WPROOT% %WPSADMIN% %WPSPSWD% %HOSTNAME% %PORT%
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

:noWP

REM ###########################################################################
REM ########## Activate configuration                                ##########
REM ###########################################################################

REM ----------------------------------------------------------------------------
REM Stop WebSphere Application Server.
REM ----------------------------------------------------------------------------
set cmdline=call "%APP_SERVER_PROFILEPATH%\bin\stopServer.bat" %APP_SERVER_NAME% -username %WASADMIN% -password %WASPSWD%
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if "%MYERRORLEVEL%"=="-10" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
if not "%MYERRORLEVEL%"=="0" goto :EXIT

REM ----------------------------------------------------------------------------
REM Stop Portal Server.
REM ----------------------------------------------------------------------------
REM set cmdline=call "%PORTAL_APP_SERVER_PROFILEPATH%\bin\stopServer" %PORTAL_APP_SERVER_NAME% -username %WPSADMIN% -password %WPSPSWD%
REM echo ++++ %DATE%:%TIME% Execute: %cmdline%
REM %cmdline%
REM set MYERRORLEVEL=%ERRORLEVEL%
REM echo ++++ %DATE%:%TIME% Executed: %cmdline%
REM echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
REM if "%MYERRORLEVEL%"=="-10" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
REM if not "%MYERRORLEVEL%"=="0" goto :EXIT

REM ----------------------------------------------------------------------------
REM Start WebSphere Application Server.
REM ----------------------------------------------------------------------------
set cmdline=call "%APP_SERVER_PROFILEPATH%\bin\startServer.bat" %APP_SERVER_NAME%
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
rem if "%MYERRORLEVEL%"=="-1" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
if not "%MYERRORLEVEL%"=="0" goto :EXIT

REM ----------------------------------------------------------------------------
REM Start Portal Server.
REM ----------------------------------------------------------------------------
REM set cmdline=call "%PORTAL_APP_SERVER_PROFILEPATH%\bin\startServer" %PORTAL_APP_SERVER_NAME%
REM echo ++++ %DATE%:%TIME% Execute: %cmdline%
REM %cmdline%
REM set MYERRORLEVEL=%ERRORLEVEL%
REM echo ++++ %DATE%:%TIME% Executed: %cmdline%
REM echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
REM rem if "%MYERRORLEVEL%"=="-1" (echo ++++ rc accepted, set to 0&set MYERRORLEVEL=0)
REM if not "%MYERRORLEVEL%"=="0" goto :EXIT


:noWPServer

%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

goto :noRulesDeploy
REM ----------------------------------------------------------------------------
REM run the CEP Rules Deployment Tool
REM ----------------------------------------------------------------------------
SET CLASSPATH=.\tools4rules\PremisesCEPCustomizationTools.jar;%LAS_LIBRARY%\jdom.jar;%WASROOT%\runtimes\com.ibm.ws.webservices.thinclient_6.1.0.jar;%CLASSPATH%

set cmdline="%WASROOT%\java\jre\bin\java.exe" com.ibm.rfid.premises.cep.tools.CEPDefinitionDeploymentTool DBURL=db2:ATLASDB DBUser=%DB2ADMIN% DBPassword=%DB2PSWD% WASBootstrapAddress=localhost:9080
echo ++++ %DATE%:%TIME% Execute: %cmdline%
%cmdline%
set MYERRORLEVEL=%ERRORLEVEL%
echo ++++ %DATE%:%TIME% Executed: %cmdline%
echo ++++ %DATE%:%TIME% rc= %MYERRORLEVEL%
if not "%MYERRORLEVEL%"=="0" goto :EXIT

:noRulesDeploy


%CURRENT_MAIN_DRIVE%
cd "%CURRENT_MAIN_PATH%"

goto :EXIT


:EXIT
exit /b %MYERRORLEVEL%
endlocal